===============================
agaro
===============================

.. image:: https://img.shields.io/travis/eddiejessup/agaro.svg
        :target: https://travis-ci.org/eddiejessup/agaro

.. image:: https://img.shields.io/pypi/v/agaro.svg
        :target: https://pypi.python.org/pypi/agaro


Framework to run models

* Free software: BSD license
* Documentation: https://agaro.readthedocs.org.

Features
--------

* TODO
